@@ -2,6 +2,7 @@ import logging
 import os
 import tempfile
 import typing
+import sys
 
 import click
 
@@ -139,7 +140,16 @@ def map_cmd(org_files: typing.Tuple[str], backend_name: str, output: str, itl: b
     type=click.IntRange(1, 8),
     help="Set the heading level of the output pdf file.",
 )
-def pdf(org_files: typing.Tuple[str], heading_level: int) -> None:
+@click.option(
+    "-E",
+    "--exit-after-preprocessing",
+    "exit_after_preprocessing",
+    show_default=True,
+    is_flag=True,
+    type=bool,
+    help="Exit after preprocessing the file and print it to stdout.",
+)
+def pdf(org_files: typing.Tuple[str], heading_level: int, exit_after_preprocessing: bool) -> None:
     """Convert ORG_FILES into pdf files."""
 
     # TODO: Test if pandoc is installed, if not report an error
@@ -181,13 +191,21 @@ def pdf(org_files: typing.Tuple[str], heading_level: int) -> None:
         for file_path in org_files:
 
             input_content = ""
-            input_content += "#+OPTIONS: tags:nil\n"
+            input_content += r"#+LATEX_HEADER: \setlength\parindent{0pt}"
+            input_content += "\n"
+            input_content += "#+OPTIONS: tags:nil"
+            input_content += "\n"
 
             if heading_level:
-                input_content += "#+OPTIONS: H:{}\n".format(heading_level)
+                input_content += "#+OPTIONS: H:{}".format(heading_level)
+                input_content += "\n"
 
             input_content += Preprocessor().preprocess_file(file_path)
 
+            if exit_after_preprocessing:
+                print(input_content)
+                sys.exit(0)
+
             # Change the compilation context to the file directory
             # this is needed in order to include images from the paths relative to org file
             os.chdir(os.path.dirname(os.path.abspath(file_path)))
@@ -199,6 +217,11 @@ def pdf(org_files: typing.Tuple[str], heading_level: int) -> None:
                 "org",
                 outputfile=of,
                 extra_args=[
+                    # TODO: Add an option to set the documentclass
+                    "-V",
+                    "documentclass=report",
+                    "-V",
+                    "block-headings",
                     "--toc",
                     "-N",
                     "-V",
@@ -210,3 +233,13 @@ def pdf(org_files: typing.Tuple[str], heading_level: int) -> None:
 
         # Restore the old working directory
         os.chdir(old_working_directory)
+
+
+@main.command()
+@click.argument("org_file", type=click.Path(exists=True), required=True, nargs=1)
+def preprocess(org_file: str) -> None:
+    """Preprocess ORG_FILES and print them to stdout.
+
+    NOTE: This is used for debugging purposes.
+    """
+    print(Preprocessor().preprocess_file(org_file))
